<?php
/*
Plugin Name: Copyright Info
Description: A shortcode to display an image inline with dynamically formatted copyright information.
Version: 1.2c
Author: SB
*/

// Create the admin menu
function copyright_info_menu() {
    add_options_page(
        'Copyright Info Settings',
        'Copyright Info',
        'manage_options',
        'copyright-info-settings',
        'copyright_info_settings_page'
    );
}
add_action('admin_menu', 'copyright_info_menu');

// Display the settings page
function copyright_info_settings_page() {
    ?>
    <div class="wrap">
        <h1>Copyright Info Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('copyright_info_settings_group');
            do_settings_sections('copyright-info-settings');
            submit_button();
            ?>
        </form>

        <h2>Preview</h2>
        <div id="copyright_info_preview" style="font-size: 14px; display: inline-flex; align-items: center; margin-top: 20px; border: 1px solid #ddd; padding: 10px;">
            <?php echo copyright_info_shortcode(); ?>
        </div>

        <h2>How to Use</h2>
        <div style="margin-top: 20px; padding: 10px; background-color: #f9f9f9; border: 1px solid #ddd;">
            <p>To display the copyright information with the selected image and text, use the following shortcode:</p>
            <pre><code>[copyright_info]</code></pre>
            <p>This shortcode will display the image and text that you have configured in the settings above. You can add this shortcode to any post, page, or widget to display the copyright info.</p>
        </div>
    </div>
    <?php
}

// Register settings, sections, and fields
function copyright_info_settings_init() {
    register_setting('copyright_info_settings_group', 'copyright_info_image');
    register_setting('copyright_info_settings_group', 'copyright_info_text');
    register_setting('copyright_info_settings_group', 'copyright_info_link');
    register_setting('copyright_info_settings_group', 'copyright_info_image_size', ['default' => '20']);
    register_setting('copyright_info_settings_group', 'copyright_info_font_size', ['default' => '14']);

    add_settings_section(
        'copyright_info_section',
        'Settings',
        null,
        'copyright-info-settings'
    );

    add_settings_field(
        'copyright_info_image',
        'Select Image',
        'copyright_info_image_field',
        'copyright-info-settings',
        'copyright_info_section'
    );

    add_settings_field(
        'copyright_info_text',
        'Custom Text',
        'copyright_info_text_field',
        'copyright-info-settings',
        'copyright_info_section'
    );

    add_settings_field(
        'copyright_info_link',
        'Text Hyperlink URL',
        'copyright_info_link_field',
        'copyright-info-settings',
        'copyright_info_section'
    );

    add_settings_field(
        'copyright_info_image_size',
        'Image Size (px)',
        'copyright_info_image_size_field',
        'copyright-info-settings',
        'copyright_info_section'
    );

    add_settings_field(
        'copyright_info_font_size',
        'Font Size (px)',
        'copyright_info_font_size_field',
        'copyright-info-settings',
        'copyright_info_section'
    );
}
add_action('admin_init', 'copyright_info_settings_init');

// Callback functions for settings fields
function copyright_info_image_field() {
    $image_id = get_option('copyright_info_image');
    $image_url = $image_id ? wp_get_attachment_url($image_id) : '';

    ?>
    <div>
        <input type="hidden" id="copyright_info_image" name="copyright_info_image" value="<?php echo esc_attr($image_id); ?>" />
        <button type="button" class="button" id="upload_image_button">Select Image</button>
        <button type="button" class="button" id="remove_image_button">Remove Image</button>
        <img id="image_preview" src="<?php echo esc_url($image_url); ?>" style="margin-top: 10px; max-width: 200px; display: <?php echo $image_url ? 'block' : 'none'; ?>;" />
    </div>
    <script>
    jQuery(document).ready(function($){
        var mediaUploader;

        $('#upload_image_button').click(function(e) {
            e.preventDefault();
            if (mediaUploader) {
                mediaUploader.open();
                return;
            }
            mediaUploader = wp.media({
                title: 'Select Image',
                button: {
                    text: 'Use this image'
                },
                multiple: false
            });
            mediaUploader.on('select', function() {
                var attachment = mediaUploader.state().get('selection').first().toJSON();
                $('#copyright_info_image').val(attachment.id);
                $('#image_preview').attr('src', attachment.url).show();
                updatePreview();
            });
            mediaUploader.open();
        });

        $('#remove_image_button').click(function() {
            $('#copyright_info_image').val('');
            $('#image_preview').hide();
            updatePreview();
        });

        $('#copyright_info_text').on('input', function() {
            updatePreview();
        });

        $('#copyright_info_link').on('input', function() {
            updatePreview();
        });

        $('#copyright_info_image_size').on('input', function() {
            updatePreview();
        });

        $('#copyright_info_font_size').on('input', function() {
            updatePreview();
        });

        function updatePreview() {
            var imageUrl = $('#image_preview').attr('src');
            var text = $('#copyright_info_text').val();
            var link = $('#copyright_info_link').val();
            var imageSize = $('#copyright_info_image_size').val() || '20';
            var fontSize = $('#copyright_info_font_size').val() || '14';

            var previewHtml = '<div style="font-size: ' + fontSize + 'px; display: inline-flex; align-items: center;">';
            if (imageUrl) {
                previewHtml += '<img src="' + imageUrl + '" alt="' + text + '" style="margin-right: 10px; width: ' + imageSize + 'px; height: ' + imageSize + 'px;" />';
            }
            previewHtml += '©<?php echo date("Y"); ?>&nbsp;';
            if (link) {
                previewHtml += '<a href="' + link + '" target="_blank">' + text + '</a>';
            } else {
                previewHtml += '<span>' + text + '</span>';
            }
            previewHtml += '</div>';
            $('#copyright_info_preview').html(previewHtml);
        }

        updatePreview(); // Initial preview update
    });
    </script>
    <?php
}

function copyright_info_text_field() {
    $text = get_option('copyright_info_text', 'Birchfield Inc.');
    ?>
    <input type="text" id="copyright_info_text" name="copyright_info_text" value="<?php echo esc_attr($text); ?>" style="width: 100%;" />
    <?php
}

function copyright_info_link_field() {
    $link = get_option('copyright_info_link', '');
    ?>
    <input type="text" id="copyright_info_link" name="copyright_info_link" value="<?php echo esc_attr($link); ?>" placeholder="https://example.com" style="width: 100%;" />
    <p class="description">Enter a URL to make the text a hyperlink.</p>
    <?php
}

function copyright_info_image_size_field() {
    $image_size = get_option('copyright_info_image_size', '20');
    ?>
    <input type="number" id="copyright_info_image_size" name="copyright_info_image_size" value="<?php echo esc_attr($image_size); ?>" style="width: 60px;" min="1" />
    <p class="description">Set the image size in pixels (e.g., 20 for 20px by 20px).</p>
    <?php
}

function copyright_info_font_size_field() {
    $font_size = get_option('copyright_info_font_size', '14');
    ?>
    <input type="number" id="copyright_info_font_size" name="copyright_info_font_size" value="<?php echo esc_attr($font_size); ?>" style="width: 60px;" min="1" />
    <p class="description">Set the font size in pixels (e.g., 14 for 14px).</p>
    <?php
}

// Shortcode to display the image and custom text
function copyright_info_shortcode() {
    $image_id = get_option('copyright_info_image');
    $image_url = $image_id ? wp_get_attachment_url($image_id) : '';
    $text = get_option('copyright_info_text', 'Birchfield Inc.');
    $link = get_option('copyright_info_link', '');
    $image_size = get_option('copyright_info_image_size', '20');
    $font_size = get_option('copyright_info_font_size', '14');

    // Fallback to default values if fields are blank
    if (empty($image_size)) {
        $image_size = '20';
    }
    if (empty($font_size)) {
        $font_size = '14';
    }

    $output = '<div style="font-size: ' . esc_attr($font_size) . 'px; display: inline-flex; align-items: center;">';
    if ($image_url) {
        $output .= '<img src="' . esc_url($image_url) . '" alt="' . esc_attr($text) . '" style="margin-right: 10px; width: ' . esc_attr($image_size) . 'px; height: ' . esc_attr($image_size) . 'px;" />';
    }
    
    $output .= '©' . date('Y') . '&nbsp;';
    
    if ($link) {
        $output .= '<a href="' . esc_url($link) . '" target="_blank">' . esc_html($text) . '</a>';
    } else {
        $output .= esc_html($text);
    }
    
    $output .= '</div>';

    return $output;
}
add_shortcode('copyright_info', 'copyright_info_shortcode');
